<?php

/**
 * Class craftit_OKThemes_Theme_Importer
 *
 * This class provides the capability to import demo content as well as import widgets and WordPress menus
 *
 */
class craftit_OKThemes_Theme_Importer {

    /**
     * Holds a copy of the object for easy reference.
     *
     * @since 2.2.0
     *
     * @var object
     */
    private static $instance;

    /**
     * Constructor. Hooks all interactions to initialize the class.
     *
     * @since 2.2.0
     */
    public function __construct() {

        self::$instance = $this;
        
        $this->theme_options_file = $this->demo_files_path . $this->theme_options_file_name;
		 
        add_action( 'admin_menu', array($this, 'craftit_add_admin') );

    }

	/**
	 * Add Panel Page
	 *
	 * @since 2.2.0
	 */
    public function craftit_add_admin() {
        //Output buffering
        ob_start();
        if ( class_exists( 'acf' ) ) {
            add_theme_page("Customizer Import", "Import theme options", 'switch_themes', 'import', array($this, 'craftit_import_option_page'));
            add_theme_page("Customizer Export", "Export theme options", 'switch_themes', 'export', array($this, 'craftit_export_option_page'));
        }
    }

    /**
     * [Import theme options]
     *
     * @since 2.2.0
     *
     */

    public function craftit_import_option_page() {
        global $wp_filesystem;
        WP_Filesystem();
    ?>
      <div class="wrap">
        <div id="icon-tools" class="icon32"><br></div>
        <h2><?php esc_html_e('Customizer Import', 'craftit');?></h2>
        <?php
        if ( isset( $_FILES['import'] ) && check_admin_referer( 'gg-customizer-import' ) ) {
          if ( $_FILES['import']['error'] > 0 ) {
            wp_die( 'An error occured.' );
          } else {
            $file_name = $_FILES['import']['name'];
            $file_name = explode( '.', $file_name );
            $file_ext  = strtolower( end( $file_name ) );
            $file_size = $_FILES['import']['size'];
            if ( ( $file_ext == 'json' ) && ( $file_size < 500000 ) ) {
              
              $encode_options = $wp_filesystem->get_contents( $_FILES['import']['tmp_name'] );

              $options        = json_decode( $encode_options, true );

              foreach ( $options as $key => $value ) {
                update_option( $key, $value );
              }

              echo '<div class="updated"><p>'.esc_html__('All options were restored successfully!', 'craftit').'</p></div>';
            } else {
              echo '<div class="error"><p>'.esc_html__('Invalid file or file size too big.', 'craftit').'</p></div>';
            }
          }
        }
        ?>
        <form method="post" enctype="multipart/form-data">
          <?php wp_nonce_field( 'gg-customizer-import' ); ?>
          <p><?php esc_html_e('If you have settings in a backup file (json) on your computer, the Import system can import it into this site. To get started, upload your backup file using the form below.', 'craftit'); ?></p>
          <p><?php esc_html_e('Choose a file (json) from your computer:', 'craftit');?> <input type="file" id="customizer-upload" name="import"></p>
          <p class="submit">
            <input type="submit" name="submit" id="customizer-submit" class="button" value="Upload file and import">
          </p>
        </form>
      </div>
    <?php
    }

    /**
     * [Export theme options]
     *
     * @since 2.2.0
     *
     */

    public function craftit_export_option_page() {
      if ( ! isset( $_POST['export'] ) ) {
      ?>
        <div class="wrap">
          <div id="icon-tools" class="icon32"><br></div>
          <h2><?php esc_html_e('Customizer Export', 'craftit');?></h2>
          <form method="post">
            <?php wp_nonce_field( 'gg-customizer-export' ); ?>
            <p><?php esc_html_e('When you click the button below, the Export system will create a backup file (json) for you to save to your computer.', 'craftit'); ?></p>
            <p><?php esc_html_e('This text file can be used to restore your settings or to easily setup another website with the same theme settings.', 'craftit'); ?></p>
            <p><em><?php esc_html_e('Please note that this export manager backs up only your theme settings and not your content. To backup your content, please use the WordPress Export Tool.', 'craftit'); ?></em></p>
            <p class="submit"><input type="submit" name="export" class="button button-primary" value="Download Backup File"></p>
          </form>
        </div>

      <?php

        $options   = get_theme_mods();

      } elseif ( check_admin_referer( 'gg-customizer-export' ) ) {

        $blogname  = strtolower( str_replace(' ', '', get_option( 'blogname' ) ) );
        $date      = date( 'm-d-Y' );
        $json_name = $blogname . '-customizer-' . $date;

        // global
        global $wpdb;

        // vars
        $theme_options = array();

        $rows = $wpdb->get_results($wpdb->prepare(
            "SELECT option_name, option_value FROM $wpdb->options WHERE option_name LIKE %s OR option_name LIKE %s",
            'options' . '_%' ,
            '_' . 'options' . '_%' 
        ), ARRAY_A);
        
        if( !empty($rows) ) {
            
            foreach( $rows as $row ) {
                
                $theme_options[ $row['option_name'] ] = maybe_unserialize($row['option_value']);
                
            }
            
        }

        ob_clean();

        echo json_encode( $theme_options );

        header( 'Content-Type: text/json; charset=' . get_option( 'blog_charset' ) );
        header( 'Content-Disposition: attachment; filename=' . $json_name . '.json' );

        exit();

      }

    	// Hook after import
    	do_action( 'okthemes_theme_import_widget_after_import' );

    	// Return results
    	return apply_filters( 'okthemes_theme_import_widget_results', $results );

    }

}

?>