<?php
require_once(  get_template_directory() . '/admin/importer/importer/okthemes-importer.php' ); //load admin theme data importer

class craftit_OKThemes_Theme_Demo_Data_Importer extends craftit_OKThemes_Theme_Importer {

    /**
     * Holds a copy of the object for easy reference.
     *
     * @since 2.2.0
     *
     * @var object
     */
    private static $instance;
    
    /**
     * Set the key to be used to store theme options
     *
     * @since 2.2.0
     *
     * @var object
     */
    public $theme_option_name         = 'craftit'; //set theme options name here
    
    public $theme_options_file_name   = 'theme_options.json';
	
    /**
     * Constructor. Hooks all interactions to initialize the class.
     *
     * @since 2.2.0
     */
    public function __construct() {
        
		$this->demo_files_path = get_template_directory() . '/admin/importer/demo-files/';

        self::$instance = $this;
		parent::__construct();

        add_action( 'admin_init', array($this, 'craftit_theme_activation') );
        add_action( 'admin_menu', array($this, 'craftit_add_admin') );
        add_action( 'admin_print_scripts', array($this, 'craftit_enqueue_admin_assets') );
    }

    // Custom assets for admin pages
    function craftit_enqueue_admin_assets() {
        wp_enqueue_style( 'craftit-theme-admin', get_template_directory_uri() . '/admin/importer/assets/admin-style.css' );
        wp_enqueue_style( 'arrows-font', get_template_directory_uri() . '/assets/arrows-font/styles.css');
    }

    // Redirect to Demo Import page after Theme activation
    public function craftit_theme_activation() {
        global $pagenow;
        if ( is_admin() AND $pagenow == 'themes.php' AND isset( $_GET['activated'] ) ) {
            //Redirect to demo import
            header( 'Location: ' . admin_url( 'admin.php?page=craftit-home' ) );
        }
    }

    /**
     * Add Panel Page
     *
     * @since 2.2.0
     */
    public function craftit_add_admin() {
        //Output buffering
        ob_start();
        add_theme_page("About the theme", "About the theme", 'switch_themes', 'craftit-home', array($this, 'craftit_welcome_page'));
        //add_theme_page("Import Demo Data", "Import Demo Data", 'switch_themes', 'craftit-demo-import', array($this, 'craftit_demo_installer'));
        if ( class_exists( 'acf' ) ) {
            add_theme_page("Customizer Import", "Import theme options", 'switch_themes', 'import', array($this, 'craftit_import_option_page'));
            add_theme_page("Customizer Export", "Export theme options", 'switch_themes', 'export', array($this, 'craftit_export_option_page'));
        }
    }


    public function craftit_welcome_page() {

        $theme = wp_get_theme();
        if ( is_child_theme() ) {
            $theme = wp_get_theme( $theme->get( 'Template' ) );
        }
        $theme_name = $theme->get( 'Name' );
        $theme_version = $theme->get( 'Version' );

        $return_url = admin_url('admin.php?page=craftit-home');

        
        ?>
        
        <div class="gg-admin-welcome-page">
            

            <div class="welcome-panel" style="padding-bottom: 23px;">
                <div class="welcome-panel-content">

                    <h2><?php echo sprintf( __( 'Welcome to <strong>%s</strong>', 'craftit' ), $theme_name . ' ' . $theme_version ) ?></h2>
                    <p class="about-description"><?php _e( 'Beautifully crafted WordPress theme ready to take your wine journey to the next level.', 'craftit' ) ?></p>

                    <div class="welcome-panel-column-container">
                        <div class="welcome-panel-column">
                            <h3><i class="dashicons dashicons-screenoptions"></i><?php _e( 'Install Plugins', 'craftit' ) ?></h3>
                            <p><?php echo sprintf( __( '%s has bundled popular premium plugins which greatly increases the flexibility of the theme. Install them in order to maximize the theme power.', 'craftit' ), $theme_name ); ?></p>
                            <a class="button button-primary" href="<?php echo admin_url( 'admin.php?page=tgmpa-install-plugins' ); ?>"><?php _e( 'Install Plugins', 'craftit' ) ?></a>
                        </div>
                        <div class="welcome-panel-column">
                            <h3><i class="dashicons dashicons-download"></i><?php _ex( 'Import Demo Content', 'noun', 'craftit' ) ?></h3>
                            <p><?php _e( 'If you have installed this theme on a clean WordPress installation then this is where you\'ll want to go next. This feature imports the demo content.', 'craftit' ) ?></p>
                            <a class="button button-primary" href="<?php echo admin_url( 'admin.php?page=fw-backups-demo-content' ); ?>">
                                <?php _e( 'Import Demo Content', 'craftit' ) ?></a>
                        </div>
                        <div class="welcome-panel-column welcome-panel-last">
                            <h3><i class="dashicons dashicons-admin-appearance"></i><?php _e( 'Customize Appearance', 'craftit' ) ?></h3>
                            <p><?php _e( 'Customize the look and feel of your site with the help of the Theme Options panel.', 'craftit' ) ?></p>
                            <a class="button button-primary" href="<?php echo admin_url( 'admin.php?page=theme-options' ); ?>"><?php _e( 'Go to Theme Options', 'craftit' ) ?></a>
                        </div>
                    </div>
                </div>
            </div>

            <div class="footer" style="display:none;">
                <ul">
                    <li>
                        <i class="dashicons dashicons-editor-help"></i>
                        <a href="#" target="_blank"><?php _e( 'Online Documentation', 'craftit' ) ?></a>
                    </li>
                    <li>
                        <i class="dashicons dashicons-sos"></i>
                        <a href="#" target="_blank"><?php _e( 'Support Portal', 'craftit' ) ?></a>
                    </li>
                    <li>
                        <i class="dashicons dashicons-backup"></i>
                        <a href="#" target="_blank"><?php _e( 'Theme Changelog', 'craftit' ) ?></a>
                    </li>
                </ul>
            </div>

        </div>
        <?php
    }     


}

new craftit_OKThemes_Theme_Demo_Data_Importer;