<?php
/**
 * Theme Functions
 *
 * @author Gogoneata Cristian <cristian.gogoneata@gmail.com>
 * @package WordPress
 * @subpackage craftit
 */

$theme = wp_get_theme();
if ( is_child_theme() ) {
    $theme = wp_get_theme( $theme->get( 'Template' ) );
}
$theme_version = $theme->get( 'Version' );

define("craftit_THEMEVERSION",$theme_version);

// Include the helpers
include (get_template_directory().'/lib/helpers.php');

// Load plugins
require_once (get_template_directory() . '/lib/class-tgm-plugin-activation.php');
include (get_template_directory() . '/lib/register-tgm-plugins.php');

//ACF
if ( class_exists( 'acf' ) ) {
    
    // ACF functions
    include get_template_directory() . '/lib/acf/acf-functions.php';

    //ACF theme customizer
    include get_template_directory() . '/lib/theme-customizer/theme-customize.php';
    
    // Hide ACF field group menu item
    add_filter('acf/settings/show_admin', '__return_false');

    // Include text domain for metaboxes
    function craftit_acf_settings_textdomain( $export_textdomain ) {
        return 'craftit';
    }
    add_filter('acf/settings/export_textdomain', 'craftit_acf_settings_textdomain');

    // ACF metaboxes
    include get_template_directory() . '/lib/metaboxes.php';

}

// ACF fields
include get_template_directory() . '/lib/acf/acf-fields.php';

// Include the importer
require_once get_template_directory() . '/admin/importer/init.php';

// Include sidebars
require_once (get_template_directory() . '/lib/sidebars.php');

// Include widgets
require_once (get_template_directory() . '/lib/widgets.php');

/**
 * Load woocommerce functions
 */
if (craftit_is_wc_activated()) {
    require_once get_template_directory() . '/lib/theme-woocommerce.php';
    require_once (get_template_directory() . '/lib/woocommerce_functions.php');
}

// Include breadcrumbs
include_once (get_template_directory() . '/lib/breadcrumbs.php');

// load custom walker menu class file
require (get_template_directory() . '/lib/nav/class-bootstrapwp_walker_nav_menu.php');

/**
 * Maximum allowed width of content within the theme.
 */
if (!isset($content_width)) {
    $content_width = 1170;
}

/**
 * Setup Theme Functions
 *
 */
if (!function_exists('craftit_theme_setup')):
    function craftit_theme_setup() {

        load_theme_textdomain('craftit', get_template_directory() . '/lang');

        add_theme_support( 'title-tag' );
        add_theme_support( 'automatic-feed-links' );
        add_theme_support( 'post-thumbnails' );
        add_theme_support( 'woocommerce' );
        add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
        add_theme_support( 'custom-header' ) ;
        $defaults = array(
            'default-color'          => 'ffffff',
            'default-image'          => '',
            'default-repeat'         => '',
            'default-position-x'     => '',
        );
        add_theme_support( 'custom-background', $defaults);

        register_nav_menus(
            array(
                'main-menu'   => esc_html__('Main Menu', 'craftit')
            )
        );

        set_post_thumbnail_size('full');
        add_image_size('craftit-nav-product-image', 150, 190, array( 'left', 'top' ));
		
        /*WooCommerce 3.x.x*/

        //add_theme_support( 'wc-product-gallery-zoom' );
        add_theme_support( 'wc-product-gallery-lightbox' );
        add_theme_support( 'wc-product-gallery-slider' );

        add_theme_support( 'woocommerce', array(
            'thumbnail_image_width'         => 9999,
            'gallery_thumbnail_image_width' => 170,
            'single_image_width'            => 9999,
        ) );

    }
endif;
add_action('after_setup_theme', 'craftit_theme_setup');


/**
 * Default font loading
 */
if ( ! function_exists( 'craftit_fonts_url' ) ) :
    function craftit_fonts_url() {
        $fonts_url = '';
        $fonts     = array();
        $subsets   = 'latin,latin-ext';

        if ( 'off' !== _x( 'on', 'Lora font: on or off', 'craftit' ) ) {
            $fonts[] = 'Lora:400,400i,700,700i';
        }

        if ( 'off' !== _x( 'on', 'Poppins font: on or off', 'craftit' ) ) {
            $fonts[] = 'Poppins:300,400,500,600,700';
        }

        $subset = _x( 'no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'craftit' );

        if ( 'cyrillic' == $subset ) {
            $subsets .= ',cyrillic,cyrillic-ext';
        } elseif ( 'greek' == $subset ) {
            $subsets .= ',greek,greek-ext';
        } elseif ( 'devanagari' == $subset ) {
            $subsets .= ',devanagari';
        } elseif ( 'vietnamese' == $subset ) {
            $subsets .= ',vietnamese';
        }

        if ( $fonts ) {
            $fonts_url = add_query_arg( array(
                'family' => urlencode( implode( '|', $fonts ) ),
                'subset' => urlencode( $subsets ),
            ), '//fonts.googleapis.com/css' );
        }

        return $fonts_url;
    }
endif;


/**
 * Load CSS styles for theme.
 *
 */
function craftit_styles_loader() {
	wp_register_script('craftit_translation_file', get_template_directory_uri() .'/js/lang.js');
	
    if( function_exists('getGoogleFonts') ) {
        getGoogleFonts(get_the_ID());
    }
    
    /*Register fonts if acf is not available*/
    if ( ! class_exists( 'acf' ) ) {
        // Add custom fonts, used in the main stylesheet.
        wp_enqueue_style( 'craftit-google-fonts', craftit_fonts_url(), array(), null );
    }

    wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/bootstrap/css/bootstrap.min.css', false, craftit_THEMEVERSION, 'all');
    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/font-awesome/css/font-awesome.min.css', false, craftit_THEMEVERSION, 'all');
    wp_enqueue_style('arrows-font', get_template_directory_uri() . '/assets/arrows-font/styles.css', false, craftit_THEMEVERSION, 'all');
    
    wp_enqueue_style('magnific-popup', get_template_directory_uri() . '/styles/magnific-popup.css', false, craftit_THEMEVERSION, 'all');

    //SlickCarousel
    wp_enqueue_style('slick', get_template_directory_uri() . '/assets/slick/slick.css', false, craftit_THEMEVERSION, 'all');

    if ( craftit_is_wc_activated() ) {
        wp_enqueue_style('craftit-woocommerce', get_template_directory_uri() . '/styles/gg-woocommerce.css', false, craftit_THEMEVERSION, 'all');
    }

    //Default stylesheet
    wp_enqueue_style('craftit-style', get_stylesheet_uri() );
	
    //Generated CSS from Unyson
	if( function_exists('craftit_get_cssUrlManager_path') ) {
		
		wp_enqueue_style('craftit-generated', craftit_get_cssUrlManager_path() . 'generated.css', false, craftit_THEMEVERSION, 'all');
		
		$post_id = get_the_ID();
		if( get_post_meta( get_the_ID(), 'craftit_has_css_file', true ) == 1){
			wp_enqueue_style('generated-'.$post_id ,craftit_get_cssUrlManager_path() .'generated-'.$post_id.'.css', false, craftit_THEMEVERSION, 'all');
		}
	}

    //Custom styling from theme options Colors and Custom CSS tab
    if ( class_exists( 'acf' ) ) {
        wp_add_inline_style( 'craftit-style', craftit_generate_dynamic_css() . _get_field('gg_css', 'option') );
    }
	
	//Localize the script with new data
	$translation_array = array(
        'username_required'  => esc_html__( 'Username is required.', 'craftit' ),	
        'email_required'     => esc_html__( 'Email is required.', 'craftit' ),
        'password_required'  => esc_html__( 'Password is required.', 'craftit' ),
        'error'              => esc_html__('Error:','craftit'),
        'myaccount_page_url' => (craftit_is_wc_activated() ? get_permalink( wc_get_page_id('myaccount') ) : ''),
        'css_path'           => trailingslashit( get_template_directory_uri() ),			
		'pick_a_image'		 => esc_html__('Pick a image:','craftit'),
		'you_can_select_just_1image'		 => esc_html__('You can select just a single image','craftit'),
	);
	wp_localize_script( 'craftit_translation_file', '__craftit__', $translation_array );

	// Enqueued script with localized data.
	wp_enqueue_script( 'craftit_translation_file' );
}

add_action('wp_enqueue_scripts', 'craftit_styles_loader');

/**
 * Load JavaScript and jQuery files for theme.
 *
 */
function craftit_scripts_loader() {

    $setBase = (is_ssl()) ? "https://" : "http://";

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }

    // Internet Explorer HTML5 support 
    wp_enqueue_script( 'html5shiv',get_template_directory_uri().'/js/html5.js', array(), '', false);
    wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

    /*Site plugins*/
    wp_enqueue_script('craftit-plugins', get_template_directory_uri() . '/js/plugins.js', array('jquery'), craftit_THEMEVERSION, true);

    /* General */
    wp_enqueue_script('craftit-custom', get_template_directory_uri() . '/js/custom.js', array('jquery'), craftit_THEMEVERSION, true);

    /* Custom scripts from theme options Custom Scripts tab */
    $custom_scripts ='';
    if (_get_field('gg_script', 'option') != '') :
        $custom_scripts = stripslashes(_get_field('gg_script', 'option'));
    endif; 
    wp_add_inline_script( 'craftit-custom', $custom_scripts );

    //Ajax
    wp_localize_script('craftit-custom', 'ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));
}
add_action('wp_enqueue_scripts', 'craftit_scripts_loader');

function craftit_add_the_modals() {
    if( craftit_is_wc_activated() ) :
        //WC minicart
        if( _get_field('gg_header_minicart', 'option', true) ) {
            get_template_part( 'parts/part', 'wc-minicart' );
        }
        //WC login/register
        if( _get_field('gg_header_account', 'option', true) ) {
            get_template_part( 'parts/woocommerce/part', 'register_login' );
        }
    endif;

    //SearchForm
    if( _get_field('gg_header_search', 'option', true) ) {
        get_template_part( 'parts/part', 'searchform-toolbar' );
    }
    
    echo '<div class="md-overlay"></div>';
}
add_action( 'wp_footer', 'craftit_add_the_modals', 100 );

/**
 * Display template for post meta information.
 *
 */
if (!function_exists('craftit_posted_on')) :
    function craftit_posted_on() {

        $date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
            esc_url( get_permalink() ),
            esc_attr( get_the_time() ),
            esc_attr( get_the_date( 'c' ) ),
            esc_html( get_the_date() )
        );

        printf($date);    

    }
endif;

if ( ! function_exists( 'craftit_posted_on_summary' ) ) :
    function craftit_posted_on_summary() {
        
        if ( is_single() ) {

            echo '<time class="updated" datetime="'. get_the_time( 'c' ) .'">'. sprintf( esc_html__( 'Posted on %s ', 'craftit' ), get_the_date() ) .'</time>';
            echo '<p class="byline author">'. esc_html__( 'by', 'craftit' ) .' <a href="'. get_author_posts_url( get_the_author_meta( 'ID' ) ) .'" rel="author" class="fn">'. get_the_author() .'</a></p>';

            $categories_list = get_the_category_list( esc_html_x( ', ', 'Used between list items, there is a space after the comma.', 'craftit' ) );
            if ( $categories_list && craftit_categorized_blog() ) {
              printf( '<span class="cat-links"><span> %1$s </span>%2$s</span>',
                _x( 'in', 'Used before category names.', 'craftit' ),
                $categories_list
              );
            }

        } else {

            if ( the_title( ' ', ' ', false ) == "" ) {
                echo '<time class="updated" datetime="'. get_the_time( 'c' ) .'">'. sprintf( '<a href="%1$s" rel="bookmark"> %2$s </a>', get_permalink(), get_the_date('F dS, Y') ) .'</time>';
            } else {
                echo '<time class="updated" datetime="'. get_the_time( 'c' ) .'">'.get_the_date('F dS, Y')  .'</time> ';
            }
			
            echo '<span class="byline author">'. esc_html__( 'By', 'craftit' ) .' <a href="'. get_author_posts_url( get_the_author_meta( 'ID' ) ) .'" rel="author" class="fn">'. get_the_author() .'</a></span>';
			$categories_list = get_the_category_list( esc_html_x( ', ', 'Used between list items, there is a space after the comma.', 'craftit' ) );
            if ( $categories_list && craftit_categorized_blog() ) {
              printf( '<span class="cat-links"><span> %1$s </span>%2$s</span>',
                _x( 'in', 'Used before category names.', 'craftit' ),
                $categories_list
              );
            }
		}

        
        
        //echo '<div class="clearfix"></div>';
    }
endif;

/**
 * Display page header
 *
 */
if ( ! function_exists( 'craftit_page_header' ) ) :

function craftit_page_header() {
	// disable this function for gallery arhive
	//if(is_post_type_archive( array('gallery_cpt')) || is_tax('gallery_cpt_cat') || is_account_page() ) return ;
    if(is_post_type_archive( array('gallery_cpt')) || is_tax('gallery_cpt_cat') ) return ;
    //Get global post id
    $post_id            = craftit_global_page_id();

    $page_header        = _get_field('gg_page_header',$post_id, true);
    $page_header_align  = _get_field('gg_page_header_align',$post_id, 'left');
    $page_title         = _get_field('gg_page_title',$post_id,true);
    $page_subtitle      = _get_field('gg_page_subtitle',$post_id,'');
    $page_breadcrumbs   = _get_field('gg_page_breadcrumbs',$post_id,false);
    
    $page_description   = _get_field('gg_page_description',$post_id,'');
    //Get product category description
    if ( is_tax( array( 'product_cat', 'product_tag' ) ) && 0 === absint( get_query_var( 'paged' ) ) ) {
        $page_description = wc_format_content( term_description() );
    }

    $page_header_slider = _get_field('gg_page_header_slider',$post_id, false);
    $rev_slider_alias   = _get_field('gg_page_header_slider_select',$post_id);

    $page_header_img_style = '';

    ?>

    <!-- Page header image -->
    <?php
        if ( has_post_thumbnail($post_id) && !is_singular('product') && !is_single() && !is_archive() && !is_search() && !is_post_type_archive() ) {
            $page_header_img_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
            $page_header_img_style = 'style="background-image: url('.$page_header_img_url[0].');"';
        }

        //Woocommerce category image
        if ( is_tax( 'product_cat') ) {
            global $wp_query;
            $cat = $wp_query->get_queried_object();
            $thumbnail_id = get_woocommerce_term_meta( $cat->term_id, 'thumbnail_id', true );
            $image = wp_get_attachment_url( $thumbnail_id );
            
            if ( $image ) {
                $page_header_img_url = $image;
                $page_header_img_style = 'style="background-image: url('.$page_header_img_url.');"';
            }
        }

        if ( is_post_type_archive( 'product' ) ) {
            $page_header_img_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
            $page_header_img_style = 'style="background-image: url('.$page_header_img_url[0].');"';
        }
    ?>
    <!-- End Page header image -->

    
    <?php if ($page_header_slider && function_exists('set_revslider_as_theme') ) : ?>
    <div class="subheader-slider">
        <div class="container">
            <?php putRevSlider(esc_html($rev_slider_alias)); ?>
        </div>
    </div>
    <div class="clearfix"></div>
    <?php endif; ?>
           
    <?php
    if ( 
        ($page_header === TRUE || $page_header === NULL) && 
        !is_front_page() &&
        !is_404() 
    ) :
    ?>
        <!-- Page meta -->
        <div class="page-meta" <?php echo $page_header_img_style;?> >

            <div class="container">
                <div class="row">
                    <div class="col-md-12">
                        
                        <div class="page-meta-wrapper">

                        <?php if ( ($page_title === TRUE OR $page_title === NULL) && !is_singular('product') )  : ?>
						<?php if(is_singular('post')){ ?>
							<div class="craftit-single-header">
								<?php $previous   = get_previous_post_link( '<div class="single_left_header_pagination">%link</div>','<span class="fa fa-long-arrow-left"></span>' );
								$next       = get_next_post_link( '<div class="single_right_header_pagination">%link</div>', '<span class="fa fa-long-arrow-right"></span>' );		
								echo wp_kses_post($previous); ?>
								<h1><?php echo craftit_wp_title(); ?></h1>							
							<?php echo wp_kses_post($next); ?>	
							</div>
							<div class="post-date">
								<time class="updated" datetime="<?php the_time( 'c' ) ; ?>"><?php echo  get_the_date(); ?></time>
							</div>
							<?php }else if(is_singular('gallery_cpt')) {?>
								<div class="craftit-gallery-single-header">
									
									<h1><?php echo craftit_wp_title(); ?></h1>	
									<div class="toRight"><a href="<?php echo esc_url('/gallery-items/'); ?>"><?php esc_html_e('View All','craftit'); ?></a></div>
								</div>
								
							<?php }else { ?>
									<h1><?php echo craftit_wp_title(); ?></h1>
							<?php } ?>
                        <?php endif; ?>

                        <?php 
                        if ( $page_breadcrumbs === TRUE OR $page_breadcrumbs === NULL ) :
                            if (function_exists('craftit_breadcrumbs')) craftit_breadcrumbs();
                        endif;
                        ?>

                        <?php if ($page_description != '' ) : ?>
                        <div class="header-page-description">
                            <?php echo wp_kses_post($page_description); ?>
                        </div>
                        <?php endif; ?>
                        </div><!-- .page-meta-wrapper -->

                    </div><!-- .col-md-12 -->
                    
                </div><!-- .row -->
            </div><!-- .container -->

        </div><!-- .page-meta -->
        <!-- End Page meta -->

    <?php endif; ?>

<?php
}
endif;

/**
 * Display template for post footer information (in single.php).
 *
 */
if (!function_exists('craftit_posted_in')) :
    function craftit_posted_in() {

    // Translators: used between list items, there is a space after the comma.
    $tag_list = get_the_tag_list('<ul class="list-inline post-tags"><li>','</li><li>','</li></ul>');

    // Translators: 1 is the tags
    if ( $tag_list ) {
        $utility_text = esc_html__( '%1$s', 'craftit' );
    } 

    printf($tag_list);

}
endif;

/**
 * Adds custom classes to the array of body classes.
 *
 */
if (!function_exists('craftit_body_classes')) :
    function craftit_body_classes($classes) {

        $page_header_align           = _get_field('gg_page_header_align',craftit_global_page_id(), 'left');
        $page_header_slider          = _get_field('gg_page_header_slider', craftit_global_page_id(), false);
        $page_header_slider_position = _get_field('gg_page_header_slider_position', craftit_global_page_id(),'under_header');


        if ( has_post_thumbnail( craftit_global_page_id() ) && !is_singular('product') && !is_single() && !is_archive() && !is_search() && !is_post_type_archive() ) {
            $classes[] = 'gg-page-has-header-image';
        }
        if ( $page_header_slider ) {
            $classes[] = 'gg-page-has-header-slider';
        }
        if ( $page_header_slider_position ) {
            $classes[] = 'gg-slider-is-'.$page_header_slider_position.'';
        }

        if ( $page_header_align ) {
            $classes[] = 'gg-page-header-align-'.$page_header_align.'';
        }

        //Header styles
        $overwrite_header_style = _get_field('gg_overwrite_header_style_on_page', craftit_global_page_id(), false);

        if ($overwrite_header_style) {
            $nav_sticky = _get_field('gg_page_sticky_menu',craftit_global_page_id(), false);
            $nav_menu = _get_field('gg_page_menu_style',craftit_global_page_id(), 'style_1');
        } else {
            $nav_sticky = _get_field('gg_sticky_menu','option', false);
            $nav_menu = _get_field('gg_menu_style','option', 'style_1');
        }
        
        if ($nav_sticky) {
            $classes[] = 'gg-has-stiky-menu';
        }

         if ($nav_menu) {
            $classes[] = 'gg-has-'.$nav_menu.'-menu';
        }
        //End header styles

        if (!is_multi_author()) {
            $classes[] = 'single-author';
        }

        if (is_page_template('theme-templates/gallery.php')) {
            $classes[] = 'gg-gallery-template';
        }

        if (!_get_field('gg_site_preloader', 'option',true)) {
            $classes[] = 'pace-not-active';
        }

        if ( craftit_is_wc_activated() && is_singular('product') ) {
            
            global $post;
            $product = wc_get_product( $post->ID );

            $gg_product_thumbnails = $product->get_gallery_image_ids( $product );
            if ( $gg_product_thumbnails ) {
                $classes[] = 'gg-product-has-thumbs';    
            }
        }

        //WPML
        if ( craftit_is_wpml_activated() ) {
            
            $classes[] = 'gg-theme-has-wpml';
            
            //WPML currency
            if ( class_exists('woocommerce_wpml') ) {
                $classes[] = 'gg-theme-has-wpml-currency';
            }
        }

        //Header style
        $header_style = _get_field('gg_header_style', 'option', 'light');
        if ( $header_style ) {
            $classes[] = 'gg-header-style-'.$header_style;
        }

        return $classes;
    }
    add_filter('body_class', 'craftit_body_classes');
endif;

/**
 * Footer extras module
 */
if (!function_exists('craftit_footer_extras')) :
    function craftit_footer_extras() { ?>
        
        <?php if( _get_field('gg_footer_extras', 'option', true) ) : ?>
        <div class="footer-extras">

            <!-- Copyright -->
            <?php if ( _get_field('gg_footer_extras_copyright', 'option', true) != '') : ?>
            <div class="footer-copyright">
                <?php echo wp_kses_post( _get_field('gg_footer_extras_copyright', 'option', '&copy; 2017 Craftit. All rights reserved') ); ?>
            </div>    
            <?php endif; ?>


        </div><!-- /footer-extras -->
        <?php endif; ?>

    <?php }
endif;


/**
 * Replaces the login header logo
 */
if (!function_exists('craftit_admin_login_style')) :
    add_action( 'login_head', 'craftit_admin_login_style' );
    function craftit_admin_login_style() {
        if ( _get_field('gg_display_admin_image_logo', 'option') ) {
            $logo = _get_field('gg_admin_logo_image', 'option');
        ?>
            <style>
            .login h1 a { 
                background-image: url( <?php echo esc_url($logo['url']); ?> ) !important; 
                background-size: <?php echo esc_attr($logo['width']); ?>px <?php echo esc_attr($logo['height']);?>px;
                width:<?php echo esc_attr($logo['width']); ?>px;
                height:<?php echo esc_attr($logo['height']); ?>px;
                margin-bottom:15px; 
            }
            </style>
        <?php
        }
    }
endif;

/* Modify the titles */
add_filter( 'get_the_archive_title', function ( $title ) {

    if( is_category() ) {
        $title = single_cat_title( '', false );
    }

    if ( is_post_type_archive() ) {
        $title = post_type_archive_title( '', false );
    }

    return $title;

});

/**
 * Theme logo
 */
if (!function_exists('craftit_logo')) :
    function craftit_logo() {
        // Displays H1 or DIV based on whether we are on the home page or not (SEO)
        $heading_tag = ( is_home() || is_front_page() ) ? 'h2' : 'div';
        
        if ( _get_field('gg_display_image_logo', 'option', false) ) {    
            
            $class="graphic";
            $margins_style = '';

            //Theme Logo
            $default_logo = array(
                'url' => get_template_directory_uri() . '/images/logo.png',
                'width' => '230',
                'height' => '64',
            );

            $logo = _get_field('gg_logo_image', 'option', $default_logo);
			
		
            //If logo is not yet imported display default logo
            if ($logo == false)
                $logo = $default_logo;


            $margins = _get_field('gg_logo_margins', 'option');

            if ($margins) {
                $margins_style = 'style="margin: '.esc_attr($margins).';"';
            }

            echo '<a class="brand" href="'.esc_url( home_url( '/' ) ).'" title="'.esc_attr( get_bloginfo('name','display')).'" rel="home">'. "\n";
            echo '<img '.$margins_style.' class="brand" src="'.esc_url($logo['url']).'" alt="'.esc_attr( get_bloginfo('name','display')).'" />'. "\n";
            echo '</a>'. "\n";
        } else {
            $class="text site-title"; 
            echo '<'.$heading_tag.' class="'.esc_attr($class).'">';
            echo '<a href="'.esc_url( home_url( '/' ) ).'" title="'.esc_attr( get_bloginfo('name','display')).'" rel="home">'.get_bloginfo('name').'</a>';
            if ( _get_field('gg_display_tagline', 'option', false) ) {
                echo '<small class="visible-desktop visible-tablet '.esc_attr($class).'">'.get_bloginfo('description').'</small>'. "\n";
            }
            echo '</'.$heading_tag.'>'. "\n";     
        } 
    }
endif;


/**
 * Admin notice for WPML and Polylang together
 */
function craftit_admin_notices() {
	if(has_action('wpml_add_language_selector') && (defined('POLYLANG_VERSION'))){    
	   ?>
		<div class="notice notice-warning is-dismissible">
			<p><?php esc_html_e( 'You have Polylang and WPML enabled! Polylang will be used!', 'craftit' ); ?></p>
		</div>
		<?php
	}
}
add_action( 'admin_notices', 'craftit_admin_notices' );


/**
 * Admin js enqueue
 */
function craftit_jsenqueque(){
	wp_register_script('craftit_admin_translation_file', get_template_directory_uri() .'/js/admin-translations.js', array('jquery'));
	wp_enqueue_script('craftit-admin-js', get_template_directory_uri() .'/js/admin.js');

		// Localize the script with new data
	$translation_array = array(
        'select_a_file' => esc_html__( 'Select a file', 'craftit' ),
        'gallery'       => esc_html__( 'gallery', 'craftit' ),
        'insert'        => esc_html__( 'Insert','craftit'),
        'save_complete' => esc_html__( 'Save Complete!','craftit'),	
	);
	wp_localize_script( 'craftit_admin_translation_file', '__craftit__', $translation_array );

	// Enqueued script with localized data.
	wp_enqueue_script( 'craftit_admin_translation_file' );
}
add_action( 'admin_enqueue_scripts', 'craftit_jsenqueque' );

/**
 * Post count - Update post view
 */
function craftit_update_post_view($content){
	if(is_single()){
		$id = get_the_id();
		$count = (int)get_post_meta($id, 'craftit_post_count',true) +1 ;
		update_post_meta($id, 'craftit_post_count', $count);
	}
	return $content; 
}
add_filter( 'the_content', 'craftit_update_post_view' );

/**
 * Move comment field to bottom
 */
function craftit_move_comment_field_to_bottom( $fields ) {
		$comment_field = $fields['comment'];
		unset( $fields['comment'] );
		$fields['comment'] = $comment_field;
		return $fields;
	}
add_filter( 'comment_form_fields', 'craftit_move_comment_field_to_bottom' );

/**
 * Post count - Increment post count 
 */
function craftit_update_social_share_count(){
	$post_id = 0;
	if(isset($_POST['post_id']))
        $post_id = (int)$_POST['post_id'];
	$social_share_count=0;
    
    if( $post_id > 0 ) {
    	$social_share_count = (int) get_post_meta($post_id,"social_share_count" , true) + 1;
    	update_post_meta( $post_id, 'social_share_count', $social_share_count  ) ;
    }
    echo craftit_get_post_count_message($social_share_count); 
    wp_die();
}
add_action( 'wp_ajax_craftit_update_social_share_count', 'craftit_update_social_share_count' );
add_action( 'wp_ajax_nopriv_craftit_update_social_share_count', 'craftit_update_social_share_count' );

/**
 * Post count - get the social share message when you click a share icon(facebook, twitter  etc. )
 */
function craftit_get_post_count_message($social_share_count = false){
	if(!$social_share_count) $social_share_count = (int) get_post_meta(get_the_id(),"social_share_count" , true);
	if($social_share_count ==0) return esc_html__('Be the first to share this post','craftit');
	
	return sprintf( esc_html__('%d Cool People Shared This Post.','craftit'),$social_share_count ); 
}

/**
 * ACF notifications
 */

//add_filter('site_transient_update_plugins', 'craftit_remove_acf_notification');
function craftit_remove_acf_notification($value) {
	 unset($value->response[ 'advanced-custom-fields-pro/acf.php' ]);
	 return $value;
}

/**
 * Query for search page to display more the 1 result
 */

add_filter('posts_orderby', 'group_by_post_type', 10, 2);
function group_by_post_type($orderby, $query) {
    global $wpdb;
    if ($query->is_search) {
        return $wpdb->posts . '.post_type DESC';
    }
    // provide a default fallback return if the above condition is not true
    return $orderby;
}

/**
 * Disable Brizy notification */
function hide_update_noticee_to_all_but_admin_users() {
    set_transient( 'fw_brz_admin_notice', 1 );
}
add_action( 'admin_head', 'hide_update_noticee_to_all_but_admin_users', 1 );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328347&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        