<?php
// Verify if woocommerce is active
if ( ! function_exists( 'craftit_is_wc_activated' ) ) {
	function craftit_is_wc_activated() {
		if ( class_exists( 'woocommerce' ) ) { 
			return true;
		} else { 
			return false;
		}
	}
}

// Verify if WPML is active
if ( ! function_exists( 'craftit_is_wpml_activated' ) ) {
	function craftit_is_wpml_activated() {
		if ( class_exists( 'SitePressLanguageSwitcher' ) ) { 
			return true; 
		} else { 
			return false;
		}
	}
}

if ( craftit_is_wpml_activated() ) {
  //Disable WPML styles
  define('ICL_DONT_LOAD_NAVIGATION_CSS', true);
  define('ICL_DONT_LOAD_LANGUAGE_SELECTOR_CSS', true);
  define('ICL_DONT_LOAD_LANGUAGES_JS', true);
}

// Hide activation and update specific parts of Slider Revolution
if( function_exists('set_revslider_as_theme') ) {

	add_action( 'init', 'craftit_rev_slider' );
	function craftit_rev_slider() {
		set_revslider_as_theme();
	}

}

//Page container
if (! function_exists('craftit_page_container')) :
function craftit_page_container( $post_id = NULL ) {
		
		global $post, $product;


		if ( $post_id != FALSE || $post_id == 'special_page' ) {
			$post = get_post( $post_id );
		}

		//Get page layout options
		if ( is_search() ) {
			$page_layout = _get_field('gg_search_page_layout', 'option', 'no_sidebar');
		} elseif ( craftit_is_wc_activated() && ( is_shop() || is_product_category() ) ) {
			$page_layout = _get_field('gg_page_layout_select', get_option( 'woocommerce_shop_page_id' ), 'no_sidebar');
		} elseif ( is_archive() || is_category() || is_tag() ) {
			$page_layout = _get_field('gg_cat_page_layout', 'option', 'no_sidebar');
		} elseif ( is_singular('product') ) {
			$page_layout = 'no_sidebar';
			//$page_layout = _get_field('gg_page_layout_select', $product->ID, 'no_sidebar');
		} else {
			$page_layout = _get_field('gg_page_layout_select', $post->ID, 'no_sidebar');
		}


  switch ($page_layout) {
	  case "with_right_sidebar":
		  $page_content_class = 'col-xs-12 col-md-9 pull-left';
		  break;
	  case "with_left_sidebar":
		  $page_content_class = 'col-xs-12 col-md-9 pull-right';
		  break;
	  case "no_sidebar":
		  $page_content_class = 'col-xs-12 col-md-12';
		  break;
	  case NULL:
		  $page_content_class = 'col-xs-12 col-md-9 pull-left';
		  break;        
  }

  echo esc_attr($page_content_class);
}
endif;

//Page sidebar
if (! function_exists('craftit_page_sidebar')) :
function craftit_page_sidebar( $post_id = NULL ) {
	
		global $post, $product;

		if ( $post_id != FALSE || $post_id == 'special_page' ) {
			$post = get_post( $post_id );
		} 
		
		//Get page layout options
		if ( is_search() ) {
			$page_layout = _get_field('gg_search_page_layout', 'option','no_sidebar');
		} elseif ( craftit_is_wc_activated() && ( is_shop() || is_product_category() ) ) {
			$page_layout = _get_field('gg_page_layout_select', get_option( 'woocommerce_shop_page_id' ), 'no_sidebar');
		} elseif ( is_archive() || is_category() || is_tag() ) {
			$page_layout = _get_field('gg_cat_page_layout', 'option','no_sidebar');
		} elseif ( is_singular('product') ) {
			$page_layout = 'no_sidebar';
			//$page_layout = _get_field('gg_page_layout_select', $product->ID, 'no_sidebar');
		} else {
			$page_layout = _get_field('gg_page_layout_select', $post->ID, 'no_sidebar');
		}

  switch ($page_layout) {
	  case "with_right_sidebar":
		  $page_sidebar_class = 'col-xs-12 col-md-3 pull-right';
		  break;
	  case "with_left_sidebar":
		   $page_sidebar_class = 'col-xs-12 col-md-3 pull-left';
		  break;
	  case "no_sidebar":
		  $page_sidebar_class = '';
		  break;
	  case NULL:
		  $page_sidebar_class = 'col-xs-12 col-md-3 pull-right';
		  break;        
  }

  if ($page_layout !== 'no_sidebar') {
  ?>
  <div class="<?php echo esc_attr($page_sidebar_class); ?>">
	  <aside class="sidebar-nav">
		  <?php get_sidebar(); ?>
	  </aside>
	  <!--/aside .sidebar-nav -->
  </div><!-- /.col-3 col-sm-3 col-lg-3 -->
  <?php } ?>
<?php }
endif;



//Get the global page id
if (! function_exists('craftit_global_page_id')) :
function craftit_global_page_id() {
  
  global $wp_query;

  if ( craftit_is_wc_activated() && is_shop() ) {
	$current_page_id = get_option( 'woocommerce_shop_page_id' );
  // If there is a post
  } elseif ( is_single() || ( is_home() && !is_front_page() ) || ( is_page() && !is_front_page() ) ) {
	$current_page_id = $wp_query->post->ID;

  } else {
	$current_page_id = '';
  }
  
  if(is_home()){
	  if('page' == get_option('show_on_front')){
		  if(is_front_page()){
			  $current_page_id = get_option('page_on_front');
		  }else{
			  $current_page_id = get_option('page_for_posts');
		  }
	  }
  }

  return $current_page_id;

}
endif;

if (! function_exists('craftit_wp_title')) :
function craftit_wp_title( $display = true ) {
  global $page, $paged;

  $search = get_query_var('s');
  $title = '';

  // If there is a post
  if ( is_single() || ( is_home() && !is_front_page() ) || ( is_page() && !is_front_page() ) ) {
	$title = single_post_title( '', false );
  }

  // If there's a post type archive
  if ( is_post_type_archive() ) {
	$post_type = get_query_var( 'post_type' );
	if ( is_array( $post_type ) )
	  $post_type = reset( $post_type );
	$post_type_object = get_post_type_object( $post_type );
	if ( ! $post_type_object->has_archive )
	  $title = post_type_archive_title( '', false );
  }

  // If there's a category or tag
  if ( is_category() || is_tag() ) {
	$title = single_term_title( '', false );
  }

  // If there's a taxonomy
  if ( is_tax() ) {
	$term = get_queried_object();
	if ( $term ) {
	  $tax = get_taxonomy( $term->taxonomy );
	  $title = single_term_title( false );
	}
  }

  // If there's an author
  if ( is_author() && ! is_post_type_archive() ) {
	$author = get_queried_object();
	if ( $author )
	  $title = $author->display_name;
  }

  // Post type archives with has_archive should override terms.
  if ( is_post_type_archive() && $post_type_object->has_archive )
	$title = post_type_archive_title( '', false );

  if ( is_year() || is_month() || is_day() ) {
	$title = get_the_archive_title();
  }

  // If it's a search
  if ( is_search() ) {
	/* translators: 1 search phrase */
	$title = sprintf(esc_html__('Search Results For: %1$s','craftit'), strip_tags($search));
  }

  if ( craftit_is_wc_activated() && (is_shop()) ) {
	$title = get_the_title(woocommerce_get_page_id( 'shop' ));
  }

  if ( craftit_is_wc_activated() && is_page() && is_wc_endpoint_url() ) {
	$endpoint = WC()->query->get_current_endpoint();
	if ( $endpoint_title = WC()->query->get_endpoint_title( $endpoint ) ) {
		$title = $endpoint_title;
	}
  }

  /**
   * Filter the text of the page title.
   *
   * @since 2.0.0
   *
   * @param string $title       Page title.
   */
  $title = apply_filters( 'wp_title', $title );

  // Send it out
  if ( $display )
	echo $title;
  else
	return $title;

}

endif;

/**
 * Display an optional post thumbnail.
 */
if ( ! function_exists( 'craftit_post_thumbnail' ) ) :
function craftit_post_thumbnail() {
  if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
	return;
  }

  if ( is_single() ) :
  ?>

  <div class="post-thumbnail">
	<?php the_post_thumbnail(); ?>
  </div><!-- .post-thumbnail -->

  <?php else : ?>

  <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
	<?php
	  the_post_thumbnail( 'post-thumbnail', array( 'alt' => get_the_title() ) );
	?>
  </a>

  <?php endif; // End is_singular()
}
endif;

/**
 * Add class to next post link
 */
function craftit_next_posts_link_css($content) { 
	return 'class="btn btn-primary"';
}
add_filter('next_posts_link_attributes', 'craftit_next_posts_link_css' );


/**
 * Prints HTML with meta information for the categories, tags.
 */
if ( ! function_exists( 'craftit_entry_meta' ) ) :
function craftit_entry_meta() {
  if ( is_sticky() && is_home() && ! is_paged() ) {
	printf( '<span class="sticky-post">%s</span>', esc_html__( 'Featured', 'craftit' ) );
  }

  $format = get_post_format();
  if ( current_theme_supports( 'post-formats', $format ) ) {
	printf( '<span class="entry-format">%1$s<a href="%2$s">%3$s</a></span>',
	  sprintf( '<span>%s: </span>', _x( 'Format', 'Used before post format.', 'craftit' ) ),
	  esc_url( get_post_format_link( $format ) ),
	  get_post_format_string( $format )
	);
  }

  if ( 'post' == get_post_type() ) {
	$tags_list = get_the_tag_list();
	if ( $tags_list ) {
	  printf( '<span class="tags-links">%1$s</span>',
		$tags_list
	  );
	}
	echo '<span class="inline-categories"><ul>';
	if(is_single()){
		echo wp_list_categories();
	}
	echo '</ul></span>';
		
  }

  if ( is_attachment() && wp_attachment_is_image() ) {
	// Retrieve attachment metadata.
	$metadata = wp_get_attachment_metadata();

	printf( '<span class="full-size-link"><span>%1$s: </span><a href="%2$s">%3$s &times; %4$s</a></span>',
	  _x( 'Full size', 'Used before full size attachment link.', 'craftit' ),
	  esc_url( wp_get_attachment_url() ),
	  $metadata['width'],
	  $metadata['height']
	);
  }

  if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
	echo '<span class="comments-link">';
	comments_popup_link( esc_html__( 'Leave a comment', 'craftit' ), esc_html__( '1 Comment', 'craftit' ), esc_html__( '% Comments', 'craftit' ) );
	echo '</span>';
  }
}
endif;


/**
 * Excerpt read more
 *
 */

function craftit_excerpt_more( $more ) {
	return '<br class="read-more-spacer"> <a class="more-link" href="'. esc_url(get_permalink( get_the_ID() )) . '">' . esc_html__('Read More', 'craftit') . '</a>';
}
add_filter( 'excerpt_more', 'craftit_excerpt_more' );

/**
 * Tags widget style
 *
 */
function craftit_tag_cloud_widget($args) {
	$args['number'] = 0; //adding a 0 will display all tags
	$args['largest'] = 11; //largest tag
	$args['smallest'] = 11; //smallest tag
	$args['unit'] = 'px'; //tag font unit
	$args['format'] = 'list'; //ul with a class of wp-tag-cloud
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'craftit_tag_cloud_widget' );

/**
 * Determine whether blog/site has more than one category.
 *
 */
function craftit_categorized_blog() {
  if ( false === ( $all_the_cool_cats = get_transient( 'gg_categories' ) ) ) {
	// Create an array of all the categories that are attached to posts.
	$all_the_cool_cats = get_categories( array(
	  'fields'     => 'ids',
	  'hide_empty' => 1,

	  // We only need to know if there is more than one category.
	  'number'     => 2,
	) );

	// Count the number of categories that are attached to the posts.
	$all_the_cool_cats = count( $all_the_cool_cats );

	set_transient( 'gg_categories', $all_the_cool_cats );
  }

  if ( $all_the_cool_cats > 1 ) {
	// This blog has more than 1 category so craftit_categorized_blog should return true.
	return true;
  } else {
	// This blog has only 1 category so craftit_categorized_blog should return false.
	return false;
  }
}

/**
 * Flush out the transients used in {@see craftit_categorized_blog()}.
 *
 */
function craftit_category_transient_flusher() {
  // Like, beat it. Dig?
  delete_transient( 'gg_categories' );
}
add_action( 'edit_category', 'craftit_category_transient_flusher' );
add_action( 'save_post',     'craftit_category_transient_flusher' );



/**
 * Display template for pagination.
 *
 */
if (!function_exists('craftit_pagination')) :
function craftit_pagination($query=null) { 
	

	$prev_arrow = is_rtl() ? '<i class="fa  fa-long-arrow-right"></i>' : '<i class="fa  fa-long-arrow-left"></i>';
	$next_arrow = is_rtl() ? '<i class="fa   fa-long-arrow-left"></i>' : '<i class="fa  fa-long-arrow-right"></i>';	

	global $wp_query;
	$query = $query ? $query : $wp_query;
	$total = $query->max_num_pages;
	$big = 999999999; // need an unlikely integer

	if( !$current_page = get_query_var('paged') )
	  $current_page = 1;
	if( get_option('permalink_structure') ) {
	  $format = 'page/%#%/';
	} else {
	  $format = '&paged=%#%';
	}

	$paginate_links = paginate_links(array(
	  'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	  'format'    => $format,
	  'current'   => max( 1, get_query_var('paged') ),
	  'total'     => $total,
	  'mid_size'    => 3,
	  'type'      => 'list',
	  'prev_text'   => $prev_arrow,
	  'next_text'   => $next_arrow,
	 ) );

	$paginate_links = str_replace( "<ul class='page-numbers'>", "<ul class='pagination'>", $paginate_links );
	$paginate_links = str_replace( '<li><span class="page-numbers dots">', "<li><a href='#'>", $paginate_links );
	$paginate_links = str_replace( "<li><span class='page-numbers current'>", "<li class='current'><a href='#'>", $paginate_links );
	$paginate_links = str_replace( '</span>', '</a>', $paginate_links );
	$paginate_links = str_replace( "<li><a href='#'>&hellip;</a></li>", "<li><span class='dots'>&hellip;</span></li>", $paginate_links );
	$paginate_links = preg_replace( '/\s*page-numbers/', '', $paginate_links );
	// Display the pagination if more than one page is found
	if ( $paginate_links ) {
	  echo '<div class="pagination">';
	  echo wp_kses_post($paginate_links);
	  echo '</div><!--// end .pagination -->';
	}

}
endif;

/**
 * Display template for comments and pingbacks.
 *
 */
if (!function_exists('craftit_comment')) :
	function craftit_comment($comment, $args, $depth)
	{
		$GLOBALS['comment'] = $comment;
		switch ($comment->comment_type) :
			case 'pingback' :
			case 'trackback' : ?>

				<li <?php comment_class('media, comment'); ?> id="comment-<?php comment_ID(); ?>">
					<div class="media-body">
						<p>
							<?php esc_html_e('Pingback:', 'craftit'); ?> <?php comment_author_link(); ?>
						</p>
					</div><!--/.media-body -->
				<?php
				break;
			default :
				// Proceed with normal comments.
				global $post; ?>

				<li <?php comment_class('media'); ?> id="li-comment-<?php comment_ID(); ?>">
						<a href="<?php echo esc_url($comment->comment_author_url); ?>" class="pull-left avatar-holder">
							<?php echo get_avatar($comment, 70); ?>
						</a>
						<div class="media-body">
							<h4 class="media-heading comment-author vcard">
								<?php
								printf('<cite class="fn">%1$s %2$s</cite>',
									get_comment_author_link(),
									// If current post author is also comment author, make it known visually.
									($comment->user_id === $post->post_author) ? '<span class="label"> ' . esc_html__(
										'Post author',
										'craftit'
									) . '</span> ' : ''); ?>
							</h4>
							<p class="meta">
								<?php printf('<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
										esc_url(get_comment_link($comment->comment_ID)),
										get_comment_time('c'),
										sprintf(
											esc_html__('%1$s at %2$s', 'craftit'),
											get_comment_date(),
											get_comment_time()
										)
									); ?> <span class="replay-button"><?php comment_reply_link( array_merge($args, array(
											'reply_text' => ' / <i class="arrow_back"></i> '. esc_html__('Reply', 'craftit'),
											'depth'      => $depth,
											'max_depth'  => $args['max_depth']
										)
									)); ?></span>
							</p>

							<?php if ('0' == $comment->comment_approved) : ?>
								<p class="comment-awaiting-moderation"><?php esc_html_e(
									'Your comment is awaiting moderation.',
									'craftit'
								); ?></p>
							<?php endif; ?>

							<?php comment_text(); ?>
													
						</div>
						<!--/.media-body -->
				<?php
				break;
		endswitch;
	}
endif;


/**
 * WPML Multi currency function
 **/
if ( ! function_exists('craftit_currency_switcher') ) { 
	function craftit_currency_switcher() {
	ob_start();
	if ( class_exists('woocommerce_wpml') && craftit_is_wc_activated() ) {
	?>

	<a href="" data-toggle="dropdown" aria-haspopup="true" class="dropdown-toggle">
		<span><?php echo get_woocommerce_currency_symbol(); ?></span>
		<span class="hidden-sm hidden-xs hidden"><?php echo get_woocommerce_currency(); ?></span>
	</a>
	<?php do_action('currency_switcher', array('format' => '%symbol%')); ?>

	<?php
	}
	return ob_get_clean();
	} 
}

/**
 * WPML - Language dropdown with flags
 **/

if ( ! function_exists('craftit_wpml_language_sel') ) {
	
	function craftit_wpml_language_sel(){
		if (craftit_is_wpml_activated()) {
			if (function_exists('icl_get_languages')) {
			  $languages = icl_get_languages('skip_missing=0&orderby=custom&order=asc');
			  if(!empty($languages)){
				  $out = '<div class="dropdown">';
				  $dropdown = '';
				  foreach ($languages as $lang) {
					  $lcode = explode('-',$lang['language_code']);
		   
					  if ($lang['active']) {
						  $button = '<a href="#" data-toggle="dropdown" aria-haspopup="true" class="dropdown-toggle"><img src="'.esc_url($lang['country_flag_url']).'" alt="'.esc_html($lang['translated_name']).'" /><span class="hidden-sm hidden-xs">'.$lang['translated_name'].'</span></a>';
					  } else {
						  $dropdown .= '<li><a href="'.esc_url($lang['url']).'" title="'.esc_html($lang['native_name']).'"><img src="'.esc_url($lang['country_flag_url']).'" alt="'.esc_html($lang['translated_name']).'" /> '.$lang['translated_name'].' </a></li>';
					  }
				  }
				  $out .= $button;
				  $out .= '<ul id="langswitch" class="dropdown-menu noclose">'.$dropdown.'</ul>';
				  $out .= '</div>';
				  return $out;
			  }
			}

		}
	}
	
}
if ( ! function_exists('craftit_get_gallery_cat') ) {
	function craftit_get_gallery_cat(){
		
		$terms = get_the_terms( get_the_id(), 'gallery_cpt_cat' );
		if($terms){
			$term_list = array();
			foreach($terms as $term){

				$term_list[] = '<a href="'.get_term_link($term).'">'.$term->name.'</a>';
			}
		}
		return implode(', ',$term_list);
	}
}