<?php
/*
 * Remove default stylesheet
 */
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/**
 * Suppress certain WooCommerce admin notices
 */
function craftit_wc_suppress_nags() {
    if ( class_exists( 'WC_Admin_Notices' ) ) {
        // Remove the "you have outdated template files" nag
        WC_Admin_Notices::remove_notice( 'template_files' );
        
        // Remove the "install pages" and "wc-install" nag
        WC_Admin_Notices::remove_notice( 'install' );
    }
}
add_action( 'wp_loaded', 'craftit_wc_suppress_nags', 99 );

/**
 * Load JavaScript for WC
 */
add_action('wp_enqueue_scripts', 'craftit_wc_scripts_loader');
function craftit_wc_scripts_loader() {
    wp_enqueue_script('woo-inputs', get_template_directory_uri() . '/js/woocommerce.js', array('jquery'), craftit_THEMEVERSION, true); 
}

/**
 * Define image sizes - filter
 */

function craftit_filter_single_catalog_wc_image_size( array $size = array() ){
    $size = array(
        'width'  => '9999',
        'height' => '9999',
        'crop'   => 1
    );
    return $size;
}

function craftit_filter_thumbnail_wc_image_size( array $size = array() ){
    $size = array(
        'width'  => '170',
        'height' => '200',
        'crop'   => 1
    );
    return $size;
}

// single
add_filter( 'woocommerce_get_image_size_shop_single', 'craftit_filter_single_catalog_wc_image_size' );
// catalog
add_filter( 'woocommerce_get_image_size_shop_catalog', 'craftit_filter_single_catalog_wc_image_size' );
// thumbnail
add_filter( 'woocommerce_get_image_size_shop_thumbnail', 'craftit_filter_thumbnail_wc_image_size' );

//Remove the filters at user input
if ( _get_field('gg_activate_product_image_sizes','option', false) === true ) {
    // single
    remove_filter( 'woocommerce_get_image_size_shop_single', 'craftit_filter_single_catalog_wc_image_size' );
    // catalog
    remove_filter( 'woocommerce_get_image_size_shop_catalog', 'craftit_filter_single_catalog_wc_image_size' );
    // thumbnail
    remove_filter( 'woocommerce_get_image_size_shop_thumbnail', 'craftit_filter_thumbnail_wc_image_size' );
}


/**
 * WooCommerce Breadcrubs
 */
function craftit_wc_breadcrumbs() {
    return array(
            'delimiter'   => ' <span class="delimiter">&frasl;</span> ',
            'wrap_before' => '<div class="gg-breadcrumbs"><i class="icon_house_alt"></i> ',
            'wrap_after'  => '</div>',
            'before'      => '',
            'after'       => '',
            'home'        => _x('Home', 'breadcrumb', 'craftit'),
        );
}
add_filter( 'woocommerce_breadcrumb_defaults', 'craftit_wc_breadcrumbs' );


/**
 * Add Sold out badge
 */
include (get_template_directory().'/lib/woocommerce-sold-out.php');


/**
 * Hide shop page title
 */
add_filter('woocommerce_show_page_title', 'craftit_remove_shop_title' );
function craftit_remove_shop_title() {
    return false;
}

/** 
 * Remove product rating display on product loops
 */
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );

/** 
 * Remove product rating display on product single
 */
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );


/*
 * Add custom pagination
 */
function craftit_wc_pagination() {
    craftit_pagination();       
}
remove_action('woocommerce_after_shop_loop', 'woocommerce_pagination', 10);
add_action( 'woocommerce_after_shop_loop', 'craftit_wc_pagination', 10);

/**
 * Move price bellow short description
 */
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 25);


/*
 * Allow shortcodes in product excerpts
 */
if (!function_exists('woocommerce_template_single_excerpt')) {
   function woocommerce_template_single_excerpt( $post ) {
       global $post;
       if ($post->post_excerpt) echo '<div itemprop="description">' . do_shortcode(wpautop(wptexturize($post->post_excerpt))) . '</div>';
   }
}

/*
 * Shop page - Number of products per row
 */
add_filter('loop_shop_columns', 'craftit_shop_columns');
if (!function_exists('craftit_shop_columns')) {
    function craftit_shop_columns() {
        return _get_field('gg_shop_product_columns','option', '3');
    }
}

/*
 * Shop page - Number of products per page
 */
add_filter('loop_shop_per_page',  'craftit_shop_products_per_page', 20);
if (!function_exists('craftit_shop_products_per_page')) {
    function craftit_shop_products_per_page() {
        $product_per_page = _get_field('gg_product_per_page','option', '12');
        return $product_per_page;
    }
}


/**
 * Enable/Disable Sale Flash
 */
if ( _get_field('gg_store_sale_flash','option', true) === true ) {
    remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
    add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
} else {
    remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
}

/**
 * Enable/Disable Products price
 */


/**
 * Enable/Disable Add to cart
 */
if ( _get_field('gg_store_add_to_cart','option', true) === true ) {
    remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
    add_action('woocommerce_after_shop_loop_item_title','woocommerce_template_loop_add_to_cart',30);
} else {
    remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart',10);
}

/**
 * Options for product page
 */

/*Sale flash*/
if ( _get_field('gg_product_sale_flash','option', true) === false ) {
    remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10);
}

/*Price*/
if ( _get_field('gg_product_products_price','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 25);
}

/*Product summary*/
if ( _get_field('gg_product_products_excerpt','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20);
} 

/*Add to cart*/
if ( _get_field('gg_product_add_to_cart','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30);
}

/*Meta*/
if ( _get_field('gg_product_products_meta','option', true) === false ) {
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
    
}

//Tabs

//Disable reviews tab
if ( _get_field('gg_product_reviews_tab','option', false) === false ) {
    /**
     * Remove Review tab
     */
    add_filter( 'woocommerce_product_tabs', 'craftit_product_remove_reviews_tab', 98);
    function craftit_product_remove_reviews_tab($tabs) {
        unset($tabs['reviews']);
        return $tabs;
    }
}
//Disable attributes tab
if ( _get_field('gg_product_attributes_tab','option', true) === false ) {
    
    /**
     * Remove Attributes tab
     */
    add_filter( 'woocommerce_product_tabs', 'craftit_product_remove_attributes_tab', 98);
    function craftit_product_remove_attributes_tab($tabs) {
        unset($tabs['additional_information']);
        return $tabs;
    }
}
//Disable description tab
if ( _get_field('gg_product_description_tab','option', true) === false ) {
    /**
     * Remove Description tab
     */
    add_filter( 'woocommerce_product_tabs', 'craftit_product_remove_description_tab', 98);
    function craftit_product_remove_description_tab($tabs) {
        unset($tabs['description']);
        return $tabs;
    }
}


/**
 * Enable/Disable Related products
 */
if ( _get_field('gg_product_related_products','option', true) === true ) {
    remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
    add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);

    add_filter( 'woocommerce_output_related_products_args', 'craftit_related_products_args' );
      function craftit_related_products_args( $args ) {
        $args['posts_per_page'] = 4; // 4 related products
        $args['columns'] = 4; // arranged in 2 columns
        return $args;
    }

} else {
    remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
}

/**
 * Enable/Disable Up Sells products
 */
if ( _get_field('gg_product_upsells_products','option', true) === true ) {
    remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
    add_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );

    if ( ! function_exists( 'woocommerce_upsell_display_output' ) ) {
        function woocommerce_upsell_display_output() {
            woocommerce_upsell_display( 2,2 ); // Display 2 products in rows of 2
        }
    }

} else {
    remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
}


/**
 * Enable/Disable Cross Sells products
 */
if ( _get_field('gg_product_crosssells_products','option', true) === true ) {
    remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
    add_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_output',5 );

    if ( ! function_exists( 'woocommerce_cross_sell_output' ) ) {
        function woocommerce_cross_sell_output() {
            woocommerce_cross_sell_display( 2,2 ); // Display 2 products in rows of 2
        }
    }
} else {
    remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
}

/**
 * Catalog mode functions (must be always the last function)
 */
if ( _get_field('gg_store_catalog_mode','option', false ) === true ) {
    // Remove add to cart button from the product loop
    remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart',10);
    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
    remove_action('woocommerce_after_shop_loop_item_title','woocommerce_template_loop_add_to_cart',30);

    // Remove add to cart button from the product details page
    remove_action( 'woocommerce_before_add_to_cart_form', 'woocommerce_template_single_product_add_to_cart', 10, 2);
    
    add_filter( 'woocommerce_add_to_cart_validation', '__return_false', 10, 2 );

    // check for clear-cart get param to clear the cart
    add_action( 'init', 'craftit_wc_clear_cart_url' );
    function craftit_wc_clear_cart_url() {    
        global $woocommerce;
        if ( isset( $_GET['empty-cart'] ) ) { 
            $woocommerce->cart->empty_cart(); 
        }  
    }

    add_action( 'wp', 'craftit_check_pages_redirect');
    function craftit_check_pages_redirect() {
        $cart     = is_page( wc_get_page_id( 'cart' ) );
        $checkout = is_page( wc_get_page_id( 'checkout' ) );

        if ( $cart || $checkout ) {
            wp_redirect( esc_url( home_url( '/' ) ) );
            exit;
        }
    }
    
}

/**
 * Remove product category description - its included in page_header function
 **/
remove_action( 'woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10 );

/*Add social share*/
add_action('woocommerce_after_single_product_summary','craftit_woocommerce_navigation_sharing',10);
function craftit_woocommerce_navigation_sharing(){
    get_template_part( 'parts/part', 'socialshare-with-navigation' );
}
