<?php
if ( ! class_exists( 'Craftit_Gallery_Post_Type' ) ) :

class Craftit_Gallery_Post_Type { 

	public function __construct() {

		// Runs when the plugin is activated
		register_activation_hook( __FILE__, array( &$this, 'plugin_activation' ) );

		// Adds the gallery post type and taxonomies
		add_action( 'init', array( &$this, 'gallery_init' ) );

		// Thumbnail support for gallery posts
		add_theme_support( 'post-thumbnails', array( 'gallery' ) );

		// Adds columns in the admin view for thumbnail and taxonomies
		add_filter( 'manage_edit-gallery_cpt_columns', array( &$this, 'gallery_edit_columns' ), 10, 1 );
		add_action( 'manage_posts_custom_column', array( &$this, 'gallery_column_display' ), 10, 1 );

		// Show gallery post counts in the dashboard
		add_action( 'right_now_content_table_end', array( &$this, 'add_gallery_counts' ) );
	}

	/**
     * Flushes rewrite rules on plugin activation to ensure gallery posts don't 404.
     *
     * @link http://codex.wordpress.org/Function_Reference/flush_rewrite_rules
     *
     * @uses Craftit_Gallery_Post_Type::gallery_init()
     */
    public function plugin_activation() {

            $this->gallery_init();
            flush_rewrite_rules();
    }

    /**
     * Initiate registrations of post type and taxonomies.
     *
     * @uses Craftit_Gallery_Post_Type::register_post_type()
     * @uses Craftit_Gallery_Post_Type::register_taxonomy_category()
     */
    public function gallery_init() {
            $this->register_post_type();
    }

	protected function register_post_type() {

		/**
		 * Enable the Gallery custom post type
		 * http://codex.wordpress.org/Function_Reference/register_post_type
		 */

		$labels = array(
			'name' 				 => esc_html__( 'Gallery', 'craftit' ),
			'singular_name' 	 => esc_html__( 'Gallery Item', 'craftit' ),
			'add_new' 			 => esc_html__( 'Add New Item', 'craftit' ),
			'add_new_item' 		 => esc_html__( 'Add New Gallery Item', 'craftit' ),
			'edit_item' 		 => esc_html__( 'Edit Gallery Item', 'craftit' ),
			'new_item' 			 => esc_html__( 'Add New Gallery Item', 'craftit' ),
			'view_item' 		 => esc_html__( 'View Item', 'craftit' ),
			'search_items' 		 => esc_html__( 'Search Gallery', 'craftit' ),
			'not_found' 		 => esc_html__( 'No gallery items found', 'craftit' ),
			'not_found_in_trash' => esc_html__( 'No gallery items found in trash', 'craftit' )
		);

		$args = array(
	    	'labels' 			=> $labels,
	    	'public' 			=> true,
	    	'show_in_nav_menus' => true,
			'supports' 			=> array( 
					'title',
					'editor', 
					'thumbnail', 
					'revisions' 
			),
			'capability_type' 	=> 'post',
			'rewrite' 			=> array("slug" => 'gallery-items'), // Permalinks format
			'hierarchical' 		=> false,
			'has_archive' 		=> true,
			'menu_icon'			=> 'dashicons-format-image'
		); 

		$args = apply_filters( 'galleryposttype_args', $args );

		register_post_type( 'gallery_cpt', $args );

			$labels = array(
				'name'              => esc_html_x( 'Categories', 'Image Categories', 'craftit' ),
				'singular_name'     => esc_html_x( 'Category', 'Image category', 'craftit' ),
				'search_items'      => esc_html__( 'Search Categories', 'craftit' ),
				'all_items'         => esc_html__( 'All Categories', 'craftit' ),
				'parent_item'       => esc_html__( 'Parent Category', 'craftit' ),
				'parent_item_colon' => esc_html__( 'Parent Category:', 'craftit' ),
				'edit_item'         => esc_html__( 'Edit Category', 'craftit' ),
				'update_item'       => esc_html__( 'Update Category', 'craftit' ),
				'add_new_item'      => esc_html__( 'Add New Category', 'craftit' ),
				'new_item_name'     => esc_html__( 'New Category Name', 'craftit' ),
				'menu_name'         => esc_html__( 'Category', 'craftit' ),
			);

			$args = array(
				'hierarchical'      => true,
				'labels'            => $labels,
				'show_ui'           => true,
				'show_admin_column' => true,
				'query_var'         => true,
				'rewrite'           => array( 'slug' => 'gallery-category' ),
			);

			register_taxonomy( 'gallery_cpt_cat', array( 'gallery_cpt' ), $args );

			$labels = array(
				'name'                       => _x( 'Tags', 'Image gallery tags', 'craftit' ),
				'singular_name'              => _x( 'Tag', 'Image gallery Tag', 'craftit' ),
				'search_items'               => __( 'Search Tags', 'craftit' ),
				'popular_items'              => __( 'Popular Tags', 'craftit' ),
				'all_items'                  => __( 'All Tags', 'craftit' ),
				'parent_item'                => null,
				'parent_item_colon'          => null,
				'edit_item'                  => __( 'Edit Tag', 'craftit' ),
				'update_item'                => __( 'Update Tag', 'craftit' ),
				'add_new_item'               => __( 'Add New Tag', 'craftit' ),
				'new_item_name'              => __( 'New Tag Name', 'craftit' ),
				'separate_items_with_commas' => __( 'Separate tags with commas', 'craftit' ),
				'add_or_remove_items'        => __( 'Add or remove tags', 'craftit' ),
				'choose_from_most_used'      => __( 'Choose from the most used tags', 'craftit' ),
				'not_found'                  => __( 'No tags found.', 'craftit' ),
				'menu_name'                  => __( 'Tags', 'craftit' ),
			);

			$args = array(
				'hierarchical'          => false,
				'labels'                => $labels,
				'show_ui'               => true,
				'show_admin_column'     => true,
				'update_count_callback' => '_update_post_term_count',
				'query_var'             => true,
				'rewrite'               => array( 'slug' => 'gallery-tags' ),
			);

			register_taxonomy( 'gallery_cpt_tag', 'gallery_cpt', $args );
	
	}

	/**
	 * Add Columns to Gallery Edit Screen
	 * http://wptheming.com/2010/07/column-edit-pages/
	 */

	public function gallery_edit_columns( $gallery_columns ) {
		$gallery_columns = array(
			"cb"					=> "<input type=\"checkbox\" />",
			"title" 				=> esc_html__('Title', 'craftit'),
			"gallery_thumbnail" 	=> esc_html__('Thumbnail', 'craftit'),
			"author" 				=> esc_html__('Author', 'craftit'),
			"date" 					=> esc_html__('Date', 'craftit'),
		);

		return $gallery_columns;
	}

	public function gallery_column_display( $gallery_columns) {

		// Code from: http://wpengineer.com/display-post-thumbnail-post-page-overview
		global $post;
		switch ( $gallery_columns ) {
			
			case 'gallery_thumbnail':
				$width = (int) 50;
				$height = (int) 50;
				// Display the featured image in the column view if possible
				if ( has_post_thumbnail()) {
					the_post_thumbnail( array($width, $height) );
				} else {
					echo esc_html__('None', 'craftit');
				}
				break;

			/* Just break out of the switch statement for everything else. */
			default :
				break;				
		}
	}


	/**
     * Add Gallery count to "Right Now" dashboard widget.
     *
     * @return null Return early if gallery post type does not exist.
     */
    public function add_gallery_counts() {
            if ( ! post_type_exists( 'gallery' ) ) {
                    return;
            }

            $num_posts = wp_count_posts( 'gallery' );

            // Published items
            $href = 'edit.php?post_type=gallery';
            $num  = number_format_i18n( $num_posts->publish );
            $num  = $this->link_if_can_edit_posts( $num, $href );
            $text = _n( 'Gallery Item', 'Gallery Items', intval( $num_posts->publish ) );
            $text = $this->link_if_can_edit_posts( $text, $href );
            $this->display_dashboard_count( $num, $text );

            if ( 0 == $num_posts->pending ) {
                    return;
            }

            // Pending items
            $href = 'edit.php?post_status=pending&amp;post_type=gallery';
            $num  = number_format_i18n( $num_posts->pending );
            $num  = $this->link_if_can_edit_posts( $num, $href );
            $text = _n( 'Gallery Item Pending', 'Gallery Items Pending', intval( $num_posts->pending ) );
            $text = $this->link_if_can_edit_posts( $text, $href );
            $this->display_dashboard_count( $num, $text );
    }

    /**
     * Wrap a dashboard number or text value in a link, if the current user can edit posts.
     *
     * @param  string $value Value to potentially wrap in a link.
     * @param  string $href  Link target.
     *
     * @return string        Value wrapped in a link if current user can edit posts, or original value otherwise.
     */
    protected function link_if_can_edit_posts( $value, $href ) {
            if ( current_user_can( 'edit_posts' ) ) {
                    return '<a href="' . esc_url( $href ) . '">' . $value . '</a>';
            }
            return $value;
    }

    /**
     * Display a number and text with table row and cell markup for the dashboard counters.
     *
     * @param  string $number Number to display. May be wrapped in a link.
     * @param  string $label  Text to display. May be wrapped in a link.
     */
    protected function display_dashboard_count( $number, $label ) {
            ?>
            <tr>
                    <td class="first b b-gallery"><?php echo esc_html($number); ?></td>
                    <td class="t gallery"><?php echo esc_html($label); ?></td>
            </tr>
            <?php
    }   

}

new Craftit_Gallery_Post_Type;

endif;
?>