<?php if (!defined('FW')) die('Forbidden');

// Verify if woocommerce is active
if ( ! function_exists( 'craftit_is_wc_activated' ) ) {
	function craftit_is_wc_activated() {
		if ( class_exists( 'woocommerce' ) ) { 
			return true;
		} else { 
			return false;
		}
	}
}

//disable shortcodes
function craftit_disable_shortcodes($to_disable) {
	if( !craftit_is_wc_activated() ) {
		$to_disable[] = 'craftit_products';
		$to_disable[] = 'craftit_product_categories';
	}

	if( ! function_exists( 'mc4wp' ) ) {
		$to_disable[] = 'craftit_mailchimp';
	}

	$to_disable[] = 'button';
	$to_disable[] = 'special_heading';

	return $to_disable;
}
add_filter('fw_ext_shortcodes_disable_shortcodes', 'craftit_disable_shortcodes');


add_action('fw_post_options_update', 'craftit_cssManagerUpdateDeleted', 10, 4);

function craftit_cssManagerUpdateDeleted($post_id, $option_id, $sub_keys, $old_value) {

   if(($post_id ==0) || get_post_type($post_id) ==  'revision') return ;
	
	$options = fw_get_db_post_option($post_id); 
		$options = json_decode($options['page-builder']['json']);


		$protectedItems = array();
			foreach($options as $option){
				if($option->type == 'section'){
					craftit_onSimpleItems($option,$post_id);
					$protectedItems[] ='#uid_'. $option->atts->uid;
					//this is a section, parse it
					foreach($option->_items as $c1){
						
						if($c1->type == 'column'){
									$protectedItems[] ='#uid_'. $c1->atts->uid;
									craftit_onSimpleItems($c1,$post_id);
							//this is a column parse it
							foreach($c1->_items as $c2){
									$protectedItems[] ='#uid_'. $c2->atts->uid;
									craftit_onSimpleItems($c2,$post_id);
							}						
						}else{
							$protectedItems[] ='#uid_'. $c1->atts->uid;
							craftit_onSimpleItems($c1,$post_id);
						}
					}
				
 				}else if($option->type == 'column'){
					craftit_onSimpleItems($option,$post_id);
					$protectedItems[] ='#uid_'. $option->atts->uid;
					foreach($option->_items as $c2){
							// this is any other shortcode 
								$protectedItems[] = '#uid_'.$c2->atts->uid;
								craftit_onSimpleItems($c2,$post_id);
						}
				}else{
					$protectedItems[] = '#uid_'.$option->atts->uid;
					craftit_onSimpleItems($option,$post_id);
				}
			}

	removeGoogleFonts($post_id,$protectedItems); 		
	CssManager::get()->deleteItems($post_id,$protectedItems);
	$file = 'generated-'.$post_id.'.css';

	CssManager::get()->save($file,$post_id);
	
}
function craftit_onSimpleItems($c2,$post_id){


	
	$shortcodes = fw()->extensions->get('craftit'); 

	$ob = false;
	if(property_exists($c2,'shortcode')) $ob = $shortcodes->get_shortcode($c2->shortcode);

	if($ob && method_exists( $ob , 'onSimpleItems')){
		$ob->onSimpleItems($c2, $post_id);
		
	}else{
		// if it doesn't exist then just call the function that will process the core shortcodes
		craftit_core_onSimpleItems($c2,$post_id);
	}
		
	
}

function craftit_core_onSimpleItems($c2,$post_id){
	
	switch($c2->type){
		
		default:  break;// do nothing
		case 'section': craftit_on_section_save($c2,$post_id); break;
		case 'column':  craftit_on_column_save($c2,$post_id); break;
		case 'simple': 
			switch($c2->shortcode){
				case 'divider':  		craftit_on_divider_save($c2,$post_id); break;
				case 'media_image':  	craftit_on_media_image_save($c2,$post_id); break;
				case 'icon_box': 		craftit_on_icon_box_save($c2, $post_id); break;
				
			}
	}

}
/*  when a icon box is found
 * @param object $c2 
 * @param int $post_id
 * @return void
*/
function craftit_on_icon_box_save($c2,$post_id){
	$atts = $c2->atts;
	$uid = $atts->uid;

	if(!empty($atts->icon_color)){
		CssManager::get()->add('#uid_'.$uid.' .fw-iconbox-image', 'color',$atts->icon_color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid.' .fw-iconbox-image', 'color','general',$post_id);
	}	
}

/*  when a divider is found
 * @param object $c2 
 * @param int $post_id
 * @return void
*/
function craftit_on_divider_save($c2,$post_id){
	
	$atts = $c2->atts;
	$uid = $atts->uid;

	if(!empty($atts->style->space->height)){
		CssManager::get()->add('#uid_'.$uid, 'height',$atts->style->space->height.'px','general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'height','general',$post_id);
	}	
	// add height for tablet
	if(!empty($atts->style->space->tablet_height)){
		
		CssManager::get()->add('#uid_'.$uid, 'height',$atts->style->space->tablet_height.'px','tablet',$post_id);
	}else{
		
		CssManager::get()->remove('#uid_'.$uid, 'height','tablet',$post_id);
	}	
	// add height for mobile
	if(!empty($atts->style->space->mobile_height)){
		
		CssManager::get()->add('#uid_'.$uid, 'height',$atts->style->space->mobile_height.'px','mobile',$post_id);
	}else{
		
		CssManager::get()->remove('#uid_'.$uid, 'height','mobile',$post_id);
	}		
}
/*  when a media image is found
 * @param object $c2 
 * @param int $post_id
 * @return void
*/
function craftit_on_media_image_save($c2,$post_id){
	
	$atts = $c2->atts;
	$uid = $atts->uid;

	if(!empty($atts->margin->margin_top) || !empty($atts->margin->margin_right) || !empty($atts->margin->margin_bottom) || !empty($atts->margin->margin_left)){
			
		$atts->margin->margin_top 		= ($atts->margin->margin_top == 'auto')?'auto ':(int)$atts->margin->margin_top.'px ';
		$atts->margin->margin_right 	= ($atts->margin->margin_right == 'auto')?'auto ':(int)$atts->margin->margin_right.'px ';
		$atts->margin->margin_bottom	= ($atts->margin->margin_bottom == 'auto')?'auto ':(int)$atts->margin->margin_bottom.'px ';
		$atts->margin->margin_left 		= ($atts->margin->margin_left == 'auto')?'auto ':(int)$atts->margin->margin_left.'px ';

		CssManager::get()->add(	
								'#uid_'.$uid, 
								'margin',
								esc_attr($atts->margin->margin_top).
								esc_attr($atts->margin->margin_right).
								esc_attr($atts->margin->margin_bottom).
								esc_attr($atts->margin->margin_left),
								'general',
								$post_id
							);	
	}else{
			CssManager::get()->remove('#uid_'.$uid, 'margin', 'general', $post_id );		
	}		
}
/*  when a section is found
 * @param object $c2 
 * @param int $post_id
 * @return void
*/
function craftit_on_section_save($c2,$post_id){
	$atts = $c2->atts;
	$uid = $atts->uid;

	if(!empty($atts->background_size)){
		
		CssManager::get()->add('#uid_'.$uid, 'background-size',$atts->background_size,'general',$post_id);
	}else{
		
		CssManager::get()->remove('#uid_'.$uid, 'background-size','general',$post_id);
	}
	
		$style = empty($atts->border->border_style)?'solid':$atts->border->border_style;
		$color = empty($atts->border->border_color)?'#fff':$atts->border->border_color;
		
	if(!empty($atts->border->border_top) ){
		$width = (is_numeric($atts->border->border_top))?$atts->border->border_top.'px':$atts->border->border_top;
		CssManager::get()->add('#uid_'.$uid, 'border-top',$width.' '.$style.' '.$color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'border-top','general',$post_id);
	}
	
	if(!empty($atts->border->border_right) ){
		$width = (is_numeric($atts->border->border_right))?$atts->border->border_right.'px':$atts->border->border_right;
		CssManager::get()->add('#uid_'.$uid, 'border-right',$width.' '.$style.' '.$color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'border-right','general',$post_id);
	}
	
	if(!empty($atts->border->border_bottom) ){
		$width = (is_numeric($atts->border->border_bottom))?$atts->border->border_bottom.'px':$atts->border->border_bottom;
		CssManager::get()->add('#uid_'.$uid, 'border-bottom',$width.' '.$style.' '.$color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'border-bottom','general',$post_id);
	}

	if(!empty($atts->border->border_left) ){
		$width = (is_numeric($atts->border->border_left))?$atts->border->border_left.'px':$atts->border->border_left;
		CssManager::get()->add('#uid_'.$uid, 'border-left',$width.' '.$style.' '.$color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'border-left','general',$post_id);
	}	
	
	if ( !empty( $atts->background_color) ) {
	
		CssManager::get()->add('#uid_'.$uid, 'background-color',$atts->background_color,'general',$post_id);
	
	}else{

		CssManager::get()->remove('#uid_'.$uid, 'background-color','general',$post_id);
	}
	if ( isset( $atts->background_image ) && !empty( $atts->background_image->data->icon ) ) {

		CssManager::get()->add('#uid_'.$uid, 'background-image','url(\''.$atts->background_image->data->icon.'\')' ,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'background-image' ,'general',$post_id);
	}
	
	craftit_padding_margin($atts->padding, $uid, $post_id,'padding');
	craftit_padding_margin($atts->margin , $uid, $post_id,'margin');
}
/*  when a column is found
 * @param object $c2 
 * @param int $post_id
 * @return void
*/
function craftit_on_column_save($c2,$post_id){

	$atts = $c2->atts;
	$uid = $atts->uid;
	if(!empty($atts->background_color)){
	
		CssManager::get()->add('#uid_'.$uid, 'background-color',$atts->background_color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'background-color','general',$post_id);
	}	

		$style = empty($atts->border->border_style)?'solid':$atts->border->border_style;
		$color = empty($atts->border->border_color)?'#fff':$atts->border->border_color;
		
	if(!empty($atts->border->border_top) ){
		$width = (is_numeric($atts->border->border_top))?$atts->border->border_top.'px':$atts->border->border_top;
		CssManager::get()->add('#uid_'.$uid, 'border-top',$width.' '.$style.' '.$color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'border-top','general',$post_id);
	}
	
	if(!empty($atts->border->border_right) ){
		$width = (is_numeric($atts->border->border_right))?$atts->border->border_right.'px':$atts->border->border_right;
		CssManager::get()->add('#uid_'.$uid, 'border-right',$width.' '.$style.' '.$color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'border-right','general',$post_id);
	}
	
	if(!empty($atts->border->border_bottom) ){
		$width = (is_numeric($atts->border->border_bottom))?$atts->border->border_bottom.'px':$atts->border->border_bottom;
		CssManager::get()->add('#uid_'.$uid, 'border-bottom',$width.' '.$style.' '.$color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'border-bottom','general',$post_id);
	}

	if(!empty($atts->border->border_left) ){
		$width = (is_numeric($atts->border->border_left))?$atts->border->border_left.'px':$atts->border->border_left;
		CssManager::get()->add('#uid_'.$uid, 'border-left',$width.' '.$style.' '.$color,'general',$post_id);
	}else{
		CssManager::get()->remove('#uid_'.$uid, 'border-left','general',$post_id);
	}	
		
	if ( isset( $atts->background_image ) && !empty( $atts->background_image->data->icon ) ) {

		CssManager::get()->add('#uid_'.$uid, 'background-image','url(\''.$atts->background_image->data->icon.'\')' ,'general',$post_id);
	}else{
		
		CssManager::get()->remove('#uid_'.$uid, 'background-image','general',$post_id);
	}
	craftit_padding_margin($atts->padding, $uid, $post_id,'padding');
	craftit_padding_margin($atts->margin , $uid, $post_id,'margin');
	

}

add_action('fw_option_types_init','craftit_on_option_types_init');

function craftit_on_option_types_init(){
	require  dirname(__FILE__) . '/includes/option-types/fw-multi-inline/class-fw-option-type-fw-multi-inline.php';	
}


function _filter_theme_typography_standard_fonts( $fonts ) {

   	return array();	
   
}
add_filter( 'fw_option_type_typography_v2_standard_fonts', '_filter_theme_typography_standard_fonts' );

function craftit_unyson_add_google_fonts() {
	getGoogleFonts(get_the_id());
}